# os-qdb-protocal

[![Build Status](https://www.travis-ci.org/cfhamlet/os-qdb-protocal.svg?branch=master)](https://www.travis-ci.org/cfhamlet/os-qdb-protocal)
[![codecov](https://codecov.io/gh/cfhamlet/os-qdb-protocal/branch/master/graph/badge.svg)](https://codecov.io/gh/cfhamlet/os-qdb-protocal)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/os-qdb-protocal.svg)](https://pypi.python.org/pypi/os-qdb-protocal)
[![PyPI](https://img.shields.io/pypi/v/os-qdb-protocal.svg)](https://pypi.python.org/pypi/os-qdb-protocal)


qdb protocal.
 

# Install

`pip install os-qdb-protocal`

# Usage


# Unit Tests

`$ tox`

# License

MIT licensed.
